@@ -23,7 +23,7 @@
 #' @param n number of observations
 #' @param x,q vector of quantiles
 #' @param B number of replications for the (quasi)-Monte Carlo scheme
-#' @param log logical; if \code{TRUE}, probabilites and density are given on the log scale.
+#' @param log logical; if \code{TRUE}, probabilities and density are given on the log scale.
 #' @param mu vector of location parameters
 #' @param sigma covariance matrix
 #' @param lb vector of lower truncation limits
@@ -147,7 +147,7 @@ ptmvnorm <- function(q, mu, sigma, lb, ub, log = FALSE, type = c("mc", "qmc"), B
   
   for(i in 1:nrow(q)){
     if(any(q[i,] > ub) || any(q[i,] < lb)){
-      prob[i] <- NA
+      prob[i] <- 0
     } else{
       prob[i] <- switch(type,
                         mc = mvNcdf(l = lb - mu, u = q[i,] - mu, Sig = sigma, n = B)$prob,
